==> roughpy-0.0.2a0-cp39-cp39-win_amd64.whl: roughpy/__init__.py <==


""""""# start delvewheel patch
def _delvewheel_init_patch_1_3_8():
    import ctypes
    import os
    import platform
    import sys
    libs_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir, 'roughpy.libs'))
    is_conda_cpython = platform.python_implementation() == 'CPython' and (hasattr(ctypes.pythonapi, 'Anaconda_GetVersion') or 'packaged by conda-forge' in sys.version)
    if sys.version_info[:2] >= (3, 8) and not is_conda_cpython or sys.version_info[:2] >= (3, 10):
        if os.path.isdir(libs_dir):
            os.add_dll_directory(libs_dir)
    else:
        load_order_filepath = os.path.join(libs_dir, '.load-order-roughpy-0.0.2a0')
        if os.path.isfile(load_order_filepath):
            with open(os.path.join(libs_dir, '.load-order-roughpy-0.0.2a0')) as file:
                load_order = file.read().split()
            for lib in load_order:
                lib_path = os.path.join(os.path.join(libs_dir, lib))
                if os.path.isfile(lib_path) and not ctypes.windll.kernel32.LoadLibraryExW(ctypes.c_wchar_p(lib_path), None, 0x00000008):
                    raise OSError('Error loading {}; {}'.format(lib, ctypes.FormatError()))


_delvewheel_init_patch_1_3_8()
del _delvewheel_init_patch_1_3_8
# end delvewheel patch



import importlib.metadata as _ilm
import os
import platform

from pathlib import Path

try:
    __version__ = _ilm.version("RoughPy")
except _ilm.PackageNotFoundError:
    __version__ = "0.0.0"


def _add_dynload_location(path: Path):
    if platform.system() == "Windows":
        os.add_dll_directory(str(path))
        return




if platform.system() == "Windows":
    LIBS_DIR = Path(__file__).parent.parent / "roughpy.libs"
    if LIBS_DIR.exists():
        os.add_dll_directory(str(LIBS_DIR))

try:
    iomp = _ilm.distribution("intel-openmp")
    libs = [f for f in iomp.files if f.name.startswith("libiomp5")]
    if libs:
        _add_dynload_location(libs[0].locate().resolve().parent)
    del iomp
    del libs
except _ilm.PackageNotFoundError:
    pass


import roughpy._roughpy
from roughpy._roughpy import *

# from _roughpy import (
#     TensorKey,
#     LieKey,
#     TensorKeyIterator,
#     LieKeyIterator,
#     FreeTensor,
#     ShuffleTensor,
#     Lie,
#     Context,
#     get_context
# )
#
#
# from _roughpy import (
#     Scalar,
#     float as SPReal,
#     double as DPReal,
#     rational as Rational,
# )
#
# from _roughpy import (
#     Interval,
#     IntervalType,
#     RealInterval,
#     Dyadic,
#     DyadicInterval
# )
#
# from _roughpy import (
#     Stream,
#     LieIncrementStream,
# )
#
#

==> roughpy-0.0.3-cp39-cp39-win_amd64.whl: roughpy/__init__.py <==


""""""# start delvewheel patch
def _delvewheel_init_patch_1_3_8():
    import ctypes
    import os
    import platform
    import sys
    libs_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir, 'roughpy.libs'))
    is_conda_cpython = platform.python_implementation() == 'CPython' and (hasattr(ctypes.pythonapi, 'Anaconda_GetVersion') or 'packaged by conda-forge' in sys.version)
    if sys.version_info[:2] >= (3, 8) and not is_conda_cpython or sys.version_info[:2] >= (3, 10):
        if os.path.isdir(libs_dir):
            os.add_dll_directory(libs_dir)
    else:
        load_order_filepath = os.path.join(libs_dir, '.load-order-roughpy-0.0.3')
        if os.path.isfile(load_order_filepath):
            with open(os.path.join(libs_dir, '.load-order-roughpy-0.0.3')) as file:
                load_order = file.read().split()
            for lib in load_order:
                lib_path = os.path.join(os.path.join(libs_dir, lib))
                if os.path.isfile(lib_path) and not ctypes.windll.kernel32.LoadLibraryExW(ctypes.c_wchar_p(lib_path), None, 0x00000008):
                    raise OSError('Error loading {}; {}'.format(lib, ctypes.FormatError()))


_delvewheel_init_patch_1_3_8()
del _delvewheel_init_patch_1_3_8
# end delvewheel patch

import importlib.metadata as _ilm
import os
import platform

from pathlib import Path

try:
    __version__ = _ilm.version("RoughPy")
except _ilm.PackageNotFoundError:
    __version__ = "0.0.0"


def _add_dynload_location(path: Path):
    if platform.system() == "Windows":
        os.add_dll_directory(str(path))
        return


if platform.system() == "Windows":
    LIBS_DIR = Path(__file__).parent.parent / "roughpy.libs"
    if LIBS_DIR.exists():
        os.add_dll_directory(str(LIBS_DIR))

try:
    iomp = _ilm.distribution("intel-openmp")
    libs = [f for f in iomp.files if f.name.startswith("libiomp5")]
    if libs:
        _add_dynload_location(libs[0].locate().resolve().parent)
    del iomp
    del libs
except _ilm.PackageNotFoundError:
    pass

import roughpy._roughpy
from roughpy._roughpy import *

# from _roughpy import (
#     TensorKey,
#     LieKey,
#     TensorKeyIterator,
#     LieKeyIterator,
#     FreeTensor,
#     ShuffleTensor,
#     Lie,
#     Context,
#     get_context
# )
#
#
# from _roughpy import (
#     Scalar,
#     float as SPReal,
#     double as DPReal,
#     rational as Rational,
# )
#
# from _roughpy import (
#     Interval,
#     IntervalType,
#     RealInterval,
#     Dyadic,
#     DyadicInterval
# )
#
# from _roughpy import (
#     Stream,
#     LieIncrementStream,
# )
#
#
